@@ -7,6 +7,7 @@ Main module to generate a full stack with VPC, Cluster, Compute, Services and al
 """
 
 import re
+import warnings
 from importlib import import_module
 
 from troposphere import AWS_STACK_NAME, FindInMap, GetAtt, Ref
@@ -21,6 +22,7 @@ from ecs_composex.common.ecs_composex import X_AWS_KEY, X_KEY
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.common.tagging import add_all_tags
 from ecs_composex.compute.compute_stack import ComputeStack
+from ecs_composex.dashboards.dashboards_stack import XStack as DashboardsStack
 from ecs_composex.dns import DnsSettings
 from ecs_composex.dns.dns_records import DnsRecords
 from ecs_composex.ecs.ecs_cluster import add_ecs_cluster
@@ -28,6 +30,17 @@ from ecs_composex.ecs.ecs_stack import associate_services_to_root_stack
 from ecs_composex.vpc import vpc_params
 from ecs_composex.vpc.vpc_stack import add_vpc_to_root
 
+try:
+    from ecs_composex.ecr.ecr_scans_eval import scan_service_image
+
+    SCANS_POSSIBLE = True
+except ImportError:
+    warnings.warn(
+        "You must install ecs-composex[ECRScan] extra to use this functionality"
+    )
+    SCANS_POSSIBLE = False
+
+
 RES_REGX = re.compile(r"(^([x-]+))")
 COMPUTE_STACK_NAME = "Ec2Compute"
 VPC_STACK_NAME = "vpc"
@@ -301,6 +314,24 @@ def init_root_template(settings):
     return template
 
 
+def scan_services_images(settings):
+    """
+    Function to go over each service of each family in its final state and evaluate the ECR Image validity.
+
+    :param ecs_composex.common.settings.ComposeXSettings settings: The settings for the execution
+    :return:
+    """
+    result = 0
+    if not SCANS_POSSIBLE:
+        return result
+    for family in settings.families.values():
+        for service in family.services:
+            if scan_service_image(service, settings):
+                LOG.warn(f"{family.name}.{service.name} - vulnerabilities found")
+                result = 1
+    return result
+
+
 def generate_full_template(settings):
     """
     Function to generate the root root_template
@@ -343,5 +374,7 @@ def generate_full_template(settings):
     dns_records.associate_records_to_resources(settings, root_stack, dns_settings)
     dns_settings.associate_settings_to_nested_stacks(root_stack)
     set_services_alarms(settings)
+    if keyisset("x-dashboards", settings.compose_content):
+        dashboards_stack = DashboardsStack("dashboards", settings)
     add_all_tags(root_stack.stack_template, settings)
     return root_stack
