@@ -6,7 +6,7 @@
 Module to define the entry point for AWS Event Rules
 """
 
-from ecs_composex.common import build_template, LOG, NONALPHANUM
+from ecs_composex.common import LOG, NONALPHANUM, build_template
 from ecs_composex.common.compose_resources import XResource, set_resources
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.ecs.ecs_params import CLUSTER_NAME, FARGATE_VERSION
